==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>插件%1和系统版本不兼容。</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>蓝牙设置</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>开启</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>蓝牙设置</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 已连接</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>正在连接...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>蓝牙</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>蓝牙关闭</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>蓝牙</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>添加键盘布局</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>时间</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12小时制</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24小时制</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>时间设置</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>启用网络</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>关闭网络</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>网络设置</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>您确定要清空回收站里的%1项内容吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>此操作不可恢复</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>未知的设备</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>容量未知</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>磁盘</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>卸载全部</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>启动器</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>退出安全模式</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>任务栏安全模式</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>任务栏已进入安全模式，退出安全模式后即可正常显示</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>时尚模式</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>一直显示</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>一直隐藏</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>智能隐藏</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>插件</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>多任务视图</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>移除驻留</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>关闭有线网络</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>启用有线网络</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>关闭无线网络</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>启用无线网络</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>关闭网络</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>启用网络</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>网络设置</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>设备已禁用</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>无线网络：%1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>有线网络：%1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未连接</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>正在连接</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已连接网络但无法访问互联网</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>未插入网线</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>无线网络</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有线网络</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>连接失败</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有线网络</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>有线网络 %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>屏幕键盘</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>电源</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>电源设置</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>电量%1，剩余%2分钟</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>电量%1，剩余%2小时%3分钟</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>正在充电%1，还需%2分钟</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>正在充电%1，还需%2小时%3分钟</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>已充满</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>电量%1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>正在充电%1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>电量%1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>电量%1，已充满</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>显示桌面</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>移除驻留</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>电源</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待机</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>锁定</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>注销</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>切换帐户</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>电源设置</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>设备</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>取消静音</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>静音</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>音量设置</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>当前音量 %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>声音</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>回收站</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>回收站 - %1个文件</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>回收站 - %1个文件</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>清空</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>系统托盘</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>无线网络</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>无线网络 %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.53.orig.tar.xz: dde-dock-5.5.53/translations/dde-dock_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>插件%1和系统版本不兼容。</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>飞行模式</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>飞行模式开启</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>开启</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>飞行模式设置</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>飞行模式关闭</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>飞行模式</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>蓝牙设置</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>开启</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>蓝牙设置</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 已连接</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>正在连接...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>蓝牙</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>蓝牙关闭</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>蓝牙</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>添加键盘布局</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>时间</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12小时制</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24小时制</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>时间设置</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>您确定要清空回收站里的%1项内容吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>此操作不可恢复</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>未知的设备</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>容量未知</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>磁盘</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>卸载全部</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>启动器</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>退出安全模式</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>任务栏安全模式</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>任务栏已进入安全模式，退出安全模式后即可正常显示</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>时尚模式</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>一直显示</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>一直隐藏</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>智能隐藏</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>任务栏设置</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>多屏显示设置</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>插件区域</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>选择显示在任务栏插件区域的图标</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>时尚模式</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>高效模式</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>位置</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>一直显示</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>一直隐藏</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>智能隐藏</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>小</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>大</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>任务栏位置</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>跟随鼠标位置显示</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>仅主屏显示</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>多任务视图</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>移除驻留</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>屏幕键盘</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>电源</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>电源设置</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>电量%1，剩余%2分钟</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>电量%1，剩余%2小时%3分钟</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>正在充电%1，还需%2分钟</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>正在充电%1，还需%2小时%3分钟</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>电量%1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>正在充电%1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>电量%1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>电量%1，已充满</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>任务栏</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>显示桌面</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>移除驻留</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>电源</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待机</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>锁定</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>注销</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>切换帐户</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>电源设置</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>设备</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>取消静音</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>静音</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>音量设置</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>当前音量 %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>声音</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>回收站</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>回收站 - %1个文件</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>回收站 - %1个文件</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>移至回收站</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>清空</translation>
    </message>
</context>
</TS>
